% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% Dr. Jos Ernesto Rayas-Snchez                                 April 10, 2019
% Research Group on Computer-Aided Engineering of Circuits and Systems (CAECAS)
% Department of Electronics, Systems and Informatics                      ITESO
% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%               Two-Section Impedance Transformer (coarse model)
%
% Usage: Rc = ZTranTL2sec10to1_c(Xc,psic)
%        Xc: row vector for model design parameters (length n).
%        psic: vector of independent variables where Rc should be evaluated.
%        Rc: column vector of model responses at base point Xc.
%
% Model Functions Required: ZtranTL_2sec_c_Matlab.

function Rc = ZTranTL2sec10to1_c(Xc,psic)

% Pre-Assigned Parameters, Xp
Zo = 50;  % Reference impedance (ohms).
ZL = 500; % Load impedance (ohms).
%Z1overZo = 1.7783;  % Coefficients for Butterworth profile (10:1)
%Z2overZo = 5.6233;
Z1overZo = 1.8233; % Coefficients for Chebyshev profile (10:1, r=0.05)
Z2overZo = 5.4845;
Z1 = Z1overZo*Zo; % TL1 characteristic impedance (ohms), connected to source.
Z2 = Z2overZo*Zo; % TL2 characteristic impedance (ohms), connected to load.
epsr = 1;         % Effective dielectric constant of both TLs.
f0 = 1;           % Reference frequency for wavelength on TLs (GHz).
Xp = [Zo ZL Z1 Z2 epsr f0];

% Simulator Parameters, Ps
f = psic;
FP = length(f); % Number of frequency points.
IF = f(1);      % Initial frequency (GHz).
FF = f(FP);     % Final frequency (GHz).
Ps = [IF FF FP];

% Calculate Responses
P = [Xp Xc Ps];
[psi,R] = ZtranTL_2sec_c_Matlab(P); 
mS11 = R(:,1);
Rc = mS11;
