% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% Dr. Jos Ernesto Rayas-Snchez                                 April 10, 2019
% Research Group on Computer-Aided Engineering of Circuits and Systems (CAECAS)
% Department of Electronics, Systems and Informatics                      ITESO
% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%                  Two-Section Impedance Transformer (fine model)
%
% Usage: [psif,Rf] = ZTranTL2sec10to1_f(Xf)                                       
%        Xf: row vector for model design parameters (length n).
%        psif: column vector of independent variables where Rf was evaluated.
%        Rf: column vector of model responses at base point Xf.
%
% Model Functions Required: ZtranTL_2sec_f_Matlab.

function [psif,Rf] = ZTranTL2sec10to1_f(Xf)

% Pre-Assigned Parameters, Xp
Zo = 50;  % Reference impedance (ohms).
ZL = 500; % Load impedance (ohms).
%Z1overZo = 1.7783;  % Coefficients for Butterworth profile (10:1)
%Z2overZo = 5.6233;
Z1overZo = 1.8233; % Coefficients for Chebyshev profile (10:1, r=0.05)
Z2overZo = 5.4845;
Z1 = Z1overZo*Zo; % TL1 characteristic impedance (ohms), connected to source.
Z2 = Z2overZo*Zo; % TL2 characteristic impedance (ohms), connected to load.
epsr = 1;         % Effective dielectric constant of both TLs.
f0 = 1;           % Reference frequency for wavelength on TLs (GHz).
C1 = 0.4;         % Parasitic capacitors (pF).
C2 = 0.2;
C3 = 0.1;
Xp = [Zo ZL Z1 Z2 epsr f0 C1 C2 C3];

% Parameters of the Simulator, Ps
IF = 0.8;  % Initial frequency (GHz).
FF = 1.2;  % Final frequency (GHz).
FP = 301;  % Number of frequency points.
Ps = [IF FF FP];

% Calculate Responses
P = [Xp Xf Ps];
[psi,R] = ZtranTL_2sec_f_Matlab(P);
mS11 = R(:,1);
psif = psi;
Rf = mS11;
